@@ -55,15 +55,18 @@ def select_initial_parameters():
 class CMSEditionSelector(object):
 
     zope.interface.implements(asm.cms.IEditionSelector)
-    zope.component.adapts(asm.cms.IPage, asm.cmsui.interfaces.ICMSSkin)
+    zope.component.adapts(asm.cmsui.interfaces.ICMSSkin)
 
-    def __init__(self, page, request):
-        self.preferred = []
-        self.acceptable = []
+    def __init__(self, request):
+        pass
+
+    def select(self, page):
+        preferred = []
+        acceptable = []
         for edition in page.editions:
-            target = self.acceptable
+            target = acceptable
             if WORKFLOW_DRAFT in edition.parameters:
-                target = self.preferred
+                target = preferred
             elif WORKFLOW_PUBLIC in edition.parameters:
                 # If it's public and there is no draft, then the public
                 # version is preferred, otherwise if there is a draft, it's
@@ -73,8 +76,9 @@ class CMSEditionSelector(object):
                     draft = page.getEdition(edition.parameters.replace(
                         'workflow:*', WORKFLOW_DRAFT))
                 except KeyError:
-                    target = self.preferred
+                    target = preferred
             target.append(edition)
+        return preferred, acceptable
 
 
 class RetailEditionSelector(object):
@@ -84,12 +88,16 @@ class RetailEditionSelector(object):
         asm.cms.IPage,
         asm.cmsui.interfaces.IRetailSkin)
 
-    def __init__(self, page, request):
-        self.acceptable = []
-        self.preferred = []
+    def __init__(self, request):
+        pass
+
+    def select(self, page):
+        acceptable = []
+        preferred = []
         for edition in page.editions:
             if WORKFLOW_PUBLIC in edition.parameters:
-                self.preferred.append(edition)
+                preferred.append(edition)
+        return acceptable
 
 
 class PublishMenuItem(grok.Viewlet):
@@ -300,8 +308,8 @@ class InconsistentStateNotification(grok.Viewlet):
 
         if self.context == draft:
             if public.modified > draft.modified:
-                self.message = u"Public version has been modified after a draft has been created."
-                self.instruction = u"Be careful not to lose any corrections that may have been made in public version."
+                self.message = u"Public version has been modified after a draft has been created. Press \"Revert draft\" button to edit latest published version as a draft."
+                self.instruction = u"Be careful not to lose any corrections that may have been made in the public version."
             elif draft.modified > public.modified:
                 self.message = u"Remember to publish this draft."
                 self.instruction = u"Changes to drafts are not visible until published."
